package boshclient

import (
	"encoding/json"
	"fmt"
	"net/http"
)

func (c *Client) GetTasks(deploymentName string) ([]BoshTask, error) {
	errs := func(err error) ([]BoshTask, error) {
		return nil, err
	}

	req, err := http.NewRequest("GET", fmt.Sprintf("%s/tasks?deployment=%s", c.boshURL, deploymentName), nil)
	if err != nil {
		return errs(err)
	}

	authHeader, err := c.authHeaderBuilder.Build()
	if err != nil {
		return errs(err)
	}

	req.Header.Set("Authorization", authHeader)

	response, err := c.HTTPClient.Do(req)
	if err != nil {
		return errs(fmt.Errorf("error reaching bosh director: %s", err))
	}

	if response.StatusCode != http.StatusOK {
		// this if block is a work around for a BOSH bug where we can't get the tasks for a deleted deployment - remove once fixed!
		if response.StatusCode == http.StatusNotFound {
			return []BoshTask{{State: Done, Description: "", Result: ""}}, nil
		}
		return errs(unexpectedStatusErr(response, http.StatusOK))
	}

	var getTasksResponse []BoshTask
	defer response.Body.Close()
	if err := json.NewDecoder(response.Body).Decode(&getTasksResponse); err != nil {
		return errs(fmt.Errorf("error unmarshalling get_tasks response from bosh director: %s", err))
	}

	return getTasksResponse, nil
}
